# -*- coding: utf-8 -*-
# Generated by Django 1.11.23 on 2019-09-16 15:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0074_auto_20190904_1143'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_learner_portal',
            field=models.BooleanField(default=False, help_text='Specifies whether the enterprise learner portal site should be made known to the learner.'),
        ),
        migrations.AddField(
            model_name='enterprisecustomer',
            name='learner_portal_hostname',
            field=models.CharField(blank=True, default='', help_text='Hostname of the enterprise learner portal.', max_length=255),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_learner_portal',
            field=models.BooleanField(default=False, help_text='Specifies whether the enterprise learner portal site should be made known to the learner.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='learner_portal_hostname',
            field=models.CharField(blank=True, default='', help_text='Hostname of the enterprise learner portal.', max_length=255),
        ),
    ]
