# -*- coding: utf-8 -*-
# Generated by Django 1.11.23 on 2019-09-04 16:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0073_enterprisecustomerreportingconfiguration_uuid'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecourseenrollment',
            name='marked_done',
            field=models.BooleanField(default=False, help_text='Specifies whether a user marked this course as completed in the learner portal.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecourseenrollment',
            name='marked_done',
            field=models.BooleanField(default=False, help_text='Specifies whether a user marked this course as completed in the learner portal.'),
        ),
    ]
